@@ -21,15 +21,11 @@ import re
 import time
 import datetime
 from datetime import datetime
-from lxml import etree
-import xml.dom.minidom
-import xml.etree.ElementTree as ET
 from genie_parsers import *
 import pprint as pp
 import os
 import operator
 from ddrlib import *
-import genie_parsers
 # if running in device Guestshell import python CLI package
 try:
     import cli
